#ifndef NT2_INCLUDE_FUNCTIONS_ISROW_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISROW_HPP_INCLUDED

#include <nt2/predicates/include/functions/isrow.hpp>

#endif
